# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class PrivacyRules(TLObject):
    """Attributes:
        LAYER: ``102``

    Attributes:
        ID: ``0x50a04e45``

    Parameters:
        rules: List of either :obj:`PrivacyValueAllowContacts <pyrogram.api.types.PrivacyValueAllowContacts>`, :obj:`PrivacyValueAllowAll <pyrogram.api.types.PrivacyValueAllowAll>`, :obj:`PrivacyValueAllowUsers <pyrogram.api.types.PrivacyValueAllowUsers>`, :obj:`PrivacyValueDisallowContacts <pyrogram.api.types.PrivacyValueDisallowContacts>`, :obj:`PrivacyValueDisallowAll <pyrogram.api.types.PrivacyValueDisallowAll>`, :obj:`PrivacyValueDisallowUsers <pyrogram.api.types.PrivacyValueDisallowUsers>`, :obj:`PrivacyValueAllowChatParticipants <pyrogram.api.types.PrivacyValueAllowChatParticipants>` or :obj:`PrivacyValueDisallowChatParticipants <pyrogram.api.types.PrivacyValueDisallowChatParticipants>`
        chats: List of either :obj:`ChatEmpty <pyrogram.api.types.ChatEmpty>`, :obj:`Chat <pyrogram.api.types.Chat>`, :obj:`ChatForbidden <pyrogram.api.types.ChatForbidden>`, :obj:`Channel <pyrogram.api.types.Channel>` or :obj:`ChannelForbidden <pyrogram.api.types.ChannelForbidden>`
        users: List of either :obj:`UserEmpty <pyrogram.api.types.UserEmpty>` or :obj:`User <pyrogram.api.types.User>`

    See Also:
        This object can be returned by :obj:`account.GetPrivacy <pyrogram.api.functions.account.GetPrivacy>` and :obj:`account.SetPrivacy <pyrogram.api.functions.account.SetPrivacy>`.
    """

    __slots__ = ["rules", "chats", "users"]

    ID = 0x50a04e45
    QUALNAME = "types.account.PrivacyRules"

    def __init__(self, *, rules: list, chats: list, users: list):
        self.rules = rules  # Vector<PrivacyRule>
        self.chats = chats  # Vector<Chat>
        self.users = users  # Vector<User>

    @staticmethod
    def read(b: BytesIO, *args) -> "PrivacyRules":
        # No flags
        
        rules = TLObject.read(b)
        
        chats = TLObject.read(b)
        
        users = TLObject.read(b)
        
        return PrivacyRules(rules=rules, chats=chats, users=users)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.rules))
        
        b.write(Vector(self.chats))
        
        b.write(Vector(self.users))
        
        return b.getvalue()
