# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ImportedContact(TLObject):
    """Attributes:
        LAYER: ``102``

    Attributes:
        ID: ``0xd0028438``

    Parameters:
        user_id: ``int`` ``32-bit``
        client_id: ``int`` ``64-bit``
    """

    __slots__ = ["user_id", "client_id"]

    ID = 0xd0028438
    QUALNAME = "types.ImportedContact"

    def __init__(self, *, user_id: int, client_id: int):
        self.user_id = user_id  # int
        self.client_id = client_id  # long

    @staticmethod
    def read(b: BytesIO, *args) -> "ImportedContact":
        # No flags
        
        user_id = Int.read(b)
        
        client_id = Long.read(b)
        
        return ImportedContact(user_id=user_id, client_id=client_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.user_id))
        
        b.write(Long(self.client_id))
        
        return b.getvalue()
